==> xinit-1.3.4-12.tar.xz: etc/preremove/xinit.sh <==
if [ -f /etc/X11/xinit/startxwinrc ] && cmp -s /etc/defaults/etc/X11/xinit/startxwinrc /etc/X11/xinit/startxwinrc
then
    rm /etc/X11/xinit/startxwinrc
fi

if [ -f /etc/X11/xinit/Xclients ] && cmp -s /etc/defaults/etc/X11/xinit/Xclients /etc/X11/xinit/Xclients
then
    rm /etc/X11/xinit/Xclients
fi

if [ -f /etc/X11/xinit/xinitrc ] && cmp -s /etc/defaults/etc/X11/xinit/xinitrc /etc/X11/xinit/xinitrc
then
    rm /etc/X11/xinit/xinitrc
fi

if [ -f /etc/X11/xinit/xinitrc-common ] && cmp -s /etc/defaults/etc/X11/xinit/xinitrc-common /etc/X11/xinit/xinitrc-common
then
    rm /etc/X11/xinit/xinitrc-common
fi

if [ -f /etc/X11/xinit/xinitrc.d/localuser.sh ] && cmp -s /etc/defaults/etc/X11/xinit/xinitrc.d/localuser.sh /etc/X11/xinit/xinitrc.d/localuser.sh
then
    rm /etc/X11/xinit/xinitrc.d/localuser.sh
fi

if [ -f /etc/X11/xinit/Xsession ] && cmp -s /etc/defaults/etc/X11/xinit/Xsession /etc/X11/xinit/Xsession
then
    rm /etc/X11/xinit/Xsession
fi

if [ -f /etc/X11/Xmodmap ] && cmp -s /etc/defaults/etc/X11/Xmodmap /etc/X11/Xmodmap
then
    rm /etc/X11/Xmodmap
fi

if [ -f /etc/X11/Xresources ] && cmp -s /etc/defaults/etc/X11/Xresources /etc/X11/Xresources
then
    rm /etc/X11/Xresources
fi

case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
rm -f "$(cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}/XWin Server.lnk"
rmdir --ignore-fail-on-non-empty "$(cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"
case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
/bin/rm -f "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}/User script.lnk"
/bin/rmdir --ignore-fail-on-non-empty "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"

==> xinit-1.4.3-1.tar.xz: etc/preremove/xinit.sh <==
if [ -f /etc/X11/xinit/startxwinrc ] && cmp -s /etc/defaults/etc/X11/xinit/startxwinrc /etc/X11/xinit/startxwinrc
then
    rm /etc/X11/xinit/startxwinrc
fi

if [ -f /etc/X11/xinit/Xclients ] && cmp -s /etc/defaults/etc/X11/xinit/Xclients /etc/X11/xinit/Xclients
then
    rm /etc/X11/xinit/Xclients
fi

if [ -f /etc/X11/xinit/xinitrc ] && cmp -s /etc/defaults/etc/X11/xinit/xinitrc /etc/X11/xinit/xinitrc
then
    rm /etc/X11/xinit/xinitrc
fi

if [ -f /etc/X11/xinit/xinitrc-common ] && cmp -s /etc/defaults/etc/X11/xinit/xinitrc-common /etc/X11/xinit/xinitrc-common
then
    rm /etc/X11/xinit/xinitrc-common
fi

if [ -f /etc/X11/xinit/xinitrc.d/localuser.sh ] && cmp -s /etc/defaults/etc/X11/xinit/xinitrc.d/localuser.sh /etc/X11/xinit/xinitrc.d/localuser.sh
then
    rm /etc/X11/xinit/xinitrc.d/localuser.sh
fi

if [ -f /etc/X11/xinit/Xsession ] && cmp -s /etc/defaults/etc/X11/xinit/Xsession /etc/X11/xinit/Xsession
then
    rm /etc/X11/xinit/Xsession
fi

if [ -f /etc/X11/Xmodmap ] && cmp -s /etc/defaults/etc/X11/Xmodmap /etc/X11/Xmodmap
then
    rm /etc/X11/Xmodmap
fi

if [ -f /etc/X11/Xresources ] && cmp -s /etc/defaults/etc/X11/Xresources /etc/X11/Xresources
then
    rm /etc/X11/Xresources
fi

if [ ! -v CYGWIN_START_MENU_SUFFIX ]
then
  case $(uname -s) in *-WOW*) CYGWIN_START_MENU_SUFFIX=" (32-bit)" ;; esac
fi

rm -f "$(cygpath $CYGWINFORALL -P)/Cygwin-X${CYGWIN_START_MENU_SUFFIX}/XWin Server.lnk"
rmdir --ignore-fail-on-non-empty "$(cygpath $CYGWINFORALL -P)/Cygwin-X${CYGWIN_START_MENU_SUFFIX}"
if [ ! -v CYGWIN_START_MENU_SUFFIX ]
then
  case $(uname -s) in *-WOW*) CYGWIN_START_MENU_SUFFIX=" (32-bit)" ;; esac
fi
/bin/rm -f "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${CYGWIN_START_MENU_SUFFIX}/User .xsession script.lnk"
/bin/rmdir --ignore-fail-on-non-empty "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${CYGWIN_START_MENU_SUFFIX}"
